@@ -299,7 +299,10 @@ class ICRF(object):
         R = framelib.itrs.rotation_at(self.t)
         r = mxv(R, self.position.au)
         au, dec, sublongtiude = to_spherical(r)
-        ha = self.center.longitude.radians - sublongtiude
+        lon = getattr(self.center, 'longitude', None)
+        if lon is None:
+            raise ValueError(_hadec_message)
+        ha = lon.radians - sublongtiude
         ha += pi
         ha %= tau
         ha -= pi
@@ -508,13 +511,18 @@ class ICRF(object):
         """Return this position’s phase angle: the angle Sun-target-observer.
 
         Given a Sun object (which you can build by loading an ephemeris
-        and looking up ``eph['Sun']``), return the `Angle` between the
-        light arriving at this position’s target from the Sun and the
-        light traveling from this position’s target to the observer.
+        and looking up ``eph['Sun']``), return the `Angle` from the
+        body's point of view between light arriving from the Sun and the
+        light departing toward the observer.  This angle is 0° if the
+        observer is in the same direction as the Sun and sees the body
+        as fully illuminated, and 180° if the observer is behind the
+        body and sees only its dark side.
 
         .. versionadded:: 1.42
 
         """
+        # TODO: should we have the body .observe() the Sun, to account
+        # for light travel time?
         return self.separation_from(self.center_barycentric - sun.at(self.t))
 
     def fraction_illuminated(self, sun):
@@ -892,10 +900,14 @@ def _to_altaz(position, temperature_C, pressure_mbar):
 
     return alt, Angle(radians=az), Distance(r_au)
 
+_hadec_message = (
+    'to compute a body’s hour angle, you must observe it'
+    ' from a specific latitude and longitude on Earth'
+)
 _altaz_message = (
-    'to compute an altazimuth position, you must observe from a'
-    ' specific Earth location or from a position on another body'
-    ' loaded from a set of planetary constants'
+    'to compute altitude and azimuth, you must observe it from a specific'
+    ' latitude and longitude on Earth, or else from a location on another'
+    ' Solar System body that you have loaded from a set of planetary constants'
 )
 
 class _Fake(ICRF):  # support for deprecated frame rotation methods above
